<?php

/**
 * @license    GPL 2 (https://www.gnu.org/licenses/gpl.html)
 *
 * @author Pedro Figueira <pffilosofia@hotmail.com>
 */
$lang['picker']                = 'Extensão de encapsulamento';
$lang['column']                = 'colunas';
$lang['box']                   = 'simples caixa centralizada';
$lang['info']                  = 'caixa de informações';
$lang['tip']                   = 'caixa de dicas';
$lang['important']             = 'caixa importante';
$lang['alert']                 = 'caixa de alerta';
$lang['help']                  = 'caixa de ajuda';
$lang['download']              = 'caixa de transferência';
$lang['todo']                  = 'caixa \'para fazer\'';
$lang['clear']                 = 'limpar números racionais';
$lang['em']                    = 'com ênfase especial';
$lang['hi']                    = 'destacado';
$lang['lo']                    = 'menos significante';
