<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Katerina Katapodi <katerinakatapodi@gmail.com>
 */
$lang['picker']                = 'Wrap Plugin ';
$lang['column']                = 'στήλες ';
$lang['box']                   = 'απλό εστιασμένο κουτί ';
$lang['info']                  = 'πλαίσιο πληροφοριών';
$lang['tip']                   = 'πλαίσιο εντολών';
$lang['important']             = 'σημαντικό πλαίσιο';
$lang['alert']                 = 'πλαίσιο (κουτί)ειδοποιήσεων';
$lang['help']                  = 'πλαίσιο βοήθειας';
$lang['download']              = 'κατεβάστε πλαίσιο';
$lang['todo']                  = 'πλαίσιο todo';
$lang['clear']                 = 'σβήστε τις αμφισημίες';
$lang['em']                    = 'με ιδιαίτερη έμφαση';
$lang['hi']                    = 'φωτισμένο';
$lang['lo']                    = 'λιγότερο σημαντικό ';
