<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Petr Kajzar <petr.kajzar@lf1.cuni.cz>
 * @author Jaroslav Lichtblau <jlichtblau@seznam.cz>
 */
$lang['picker']                = 'Zásuvný modul Wrap';
$lang['column']                = 'sloupce';
$lang['box']                   = 'jednoduchý vystředěný rámeček';
$lang['info']                  = 'informační rámeček';
$lang['tip']                   = 'rámeček s radou';
$lang['important']             = 'důležitý rámeček';
$lang['alert']                 = 'výstražný rámeček';
$lang['help']                  = 'pomocný rámeček';
$lang['download']              = 'rámeček s odkazem ke stažení';
$lang['todo']                  = 'rámeček úkolu';
$lang['clear']                 = 'oddělovač plovoucích rámečků';
$lang['em']                    = 'zvláštně zdůrazněné';
$lang['hi']                    = 'zvýrazněné';
$lang['lo']                    = 'méně důležité';
