<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Marek Adamski <fevbew@wp.pl>
 * @author Bartek S <sadupl@gmail.com>
 */
$lang['picker']                = 'Wtyczka Wrap';
$lang['column']                = 'kolumny';
$lang['box']                   = 'wyśrodkowane proste pole';
$lang['info']                  = 'pole informacyjne';
$lang['tip']                   = 'pole sugestii';
$lang['important']             = 'ważne pole';
$lang['alert']                 = 'pole ostrzeżenia';
$lang['help']                  = 'pole pomocy';
$lang['download']              = 'pole pobierania';
$lang['todo']                  = 'pole todo';
$lang['clear']                 = 'wyczyść elementy pływające';
$lang['em']                    = 'szczególnie podkreślone';
$lang['hi']                    = 'podświetlone';
$lang['lo']                    = 'mniej znaczące';
