<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Aleksandr Selivanov <alexgearbox@gmail.com>
 * @author Ilya Rozhkov <impeck@ya.ru>
 */
$lang['picker']                = 'Wrap';
$lang['column']                = 'колонки';
$lang['box']                   = 'простой центрированный блок';
$lang['info']                  = 'блок «Информация»';
$lang['tip']                   = 'блок «Подсказка»';
$lang['important']             = 'блок «Важно»';
$lang['alert']                 = 'блок «Тревога»';
$lang['help']                  = 'блок «Справка»';
$lang['download']              = 'блок «Скачивание»';
$lang['todo']                  = 'блок «Список задач»';
$lang['clear']                 = 'очистить float’ы';
$lang['em']                    = 'пометить важным';
$lang['hi']                    = 'выделить (маркер)';
$lang['lo']                    = 'пометить неважным';
