<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Oleksiy <alexey.furashev@gmail.com>
 */
$lang['picker']                = 'Плагін Оформлення';
$lang['column']                = 'колонки';
$lang['box']                   = 'простий блок по центру';
$lang['info']                  = 'інформаційний блок';
$lang['tip']                   = 'блок з порадою';
$lang['important']             = 'важливий блок';
$lang['alert']                 = 'блок із застереженням';
$lang['help']                  = 'блок допомоги';
$lang['download']              = 'блок завантаження';
$lang['todo']                  = 'блок завдання';
$lang['em']                    = 'особливо підкреслено';
$lang['hi']                    = 'виокремити';
$lang['lo']                    = 'менш значущий';
