<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author qezwan <qezwan@gmail.com>
 */
$lang['picker']                = 'زیادکراوەی Wrap ';
$lang['column']                = 'ستونەکان';
$lang['box']                   = 'سندوقی ناوەندی سادە';
$lang['info']                  = 'سندوقی زانیاری';
$lang['tip']                   = 'سندوقی خاڵ';
$lang['important']             = 'سندوقی گرینگی';
$lang['alert']                 = 'سندوقی هۆشدار';
$lang['help']                  = 'سندوقی یارمەتی';
$lang['download']              = 'سندوقی داگرتن';
$lang['todo']                  = 'سندوقی ئەنجامدان';
$lang['clear']                 = 'سەرئاوکەوتن';
$lang['em']                    = 'بەتایبەتی جەختی لەسەر';
$lang['hi']                    = 'تیشکخراوە';
$lang['lo']                    = 'کەمتر بەرچاو';
