<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Minh <phandinhminh@protonmail.ch>
 * @author Thien Hau <thienhausoftware@gmail.com>
 */
$lang['picker']                = 'Tiện ích plugin cho Wrap';
$lang['column']                = 'cột';
$lang['box']                   = 'hộp đơn giản căn giữa';
$lang['info']                  = 'hộp thông tin';
$lang['tip']                   = 'hộp mẹo';
$lang['important']             = 'hộp quan trọng';
$lang['alert']                 = 'hộp cảnh báo';
$lang['help']                  = 'hộp trợ giúp';
$lang['download']              = 'hộp tải về';
$lang['todo']                  = 'hộp cần làm';
$lang['clear']                 = 'xóa nổi';
$lang['em']                    = 'đặc biệt nhấn mạnh';
$lang['hi']                    = 'đặc biệt nhấn mạnh';
$lang['lo']                    = 'ít nghĩa quan trọng';
