<?php
/*
 * Wrap plugin, default configuration settings
 *
 */

$conf['noPrefix'] = 'tabs, group';
$conf['restrictedClasses'] = ''; //restrict usage of plugin to these classes (comma separated)
$conf['restrictionType'] = 0; //0= exclude restricted classes, 1=include restricted classes and exclude all others
$conf['syntaxDiv'] = 'WRAP';
$conf['syntaxSpan'] = 'wrap';
$conf['darkTpl'] = 0;
$conf['emulatedHeadlines'] = 0;
